/**
 * CTU Open Contest 2009
 * Solution for the problem: Odd Opportunities
 * October, 2009
 *
 * @author Jan Stoklasa
 */

import java.util.LinkedList;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Queue;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.StringTokenizer;

public class oo {  

	 final static String newline = System.getProperty("line.separator");

	 enum Parity {odd,even};

	 class ArrayListOfIntegers extends ArrayList<Integer>
	 {
		  static final long serialVersionUID=1L;    //shut up the warning
	 }

	 class Incidence
	 {
		  int v;
		  int edge;
		  Incidence(int v, int edge)
		  {
				this.v=v;this.edge=edge;
		  }
	 }
	 
	 class Node
	 {
		  public LinkedList<Incidence> incidence;
		  public Parity parity;
		  int component;
		  boolean processed;

		  int visited;		     //BFS
		  int p;                   
		  int d;

		  public Node()
		  {
				incidence=new LinkedList<Incidence>();
				parity=Parity.even;
				component=0;
				processed=false;
				visited=0;
				p=-1;
				d=-1;
		  }
	 }

	 class Edge
	 {
		  int v1;
		  int v2;
		  int in_result;
		  
		  Edge(int vertex1,int vertex2)
		  {
				v1=vertex1;
				v2=vertex2;
				in_result=0;
		  }
	 }

	 class Graph
	 {
		  Node nodes[];
		  ArrayList<Edge> edges;
		  Graph(int NumberOfNodes, int NumberOfEdges)
		  {
				nodes=new Node[NumberOfNodes+1];   // nodes numbered from 1
				edges=new ArrayList<Edge>(NumberOfEdges);
				for(int i=1;i<nodes.length;i++)
				{
					 nodes[i]=new Node();
					 nodes[i].component=i;
				}
		  }

		  public void addEdge(int v1,int v2)
		  {
				if(v1!=v2) //ignore self-loops
				{
					 edges.add(new Edge(v1,v2));
					 nodes[v1].incidence.add(new Incidence(v2,edges.size()-1));
					 nodes[v2].incidence.add(new Incidence(v1,edges.size()-1));
				}
		  }

		  int getComponent(int node)
		  {
				int v=node;
				while(nodes[v].component!=v)
				{
					 v=nodes[v].component;
				}				
				return v;
		  }

		  public void addEdgeToSpanningForrest(int v1, int v2)
		  {		
				int c1=getComponent(v1),
					 c2=getComponent(v2);
				if(c1!=c2)
				{
					 addEdge(v1,v2);
					 nodes[c1].component=c2;
					 nodes[v1].component=c2;
					 nodes[v2].component=c2;
				}			  
		  }

		  private int thisIteration=0;
		  ArrayList<Integer> findPathToOdd(int start_vertex)
		  {
				thisIteration++;
				LinkedList<Integer> queue=new LinkedList<Integer>();
				queue.add(start_vertex);
				nodes[start_vertex].processed=true;
				nodes[start_vertex].visited=thisIteration;
				nodes[start_vertex].p=-1;
				while(!queue.isEmpty())
				{
					 int v=queue.poll();
					 if(nodes[v].parity==Parity.odd&&
						 !nodes[v].processed)
					 {						  
						  nodes[v].processed=true;
						  ArrayList<Integer> path=new ArrayList<Integer>(1000);
						  while(v!=start_vertex)
						  {
								path.add(nodes[v].d);
								v=nodes[v].p;
						  }
						  return path;
					 }
					 else
					 {
						  Iterator<Incidence> itr=nodes[v].incidence.iterator();
						  while(itr.hasNext())
						  {
								Incidence u=itr.next();
								if(nodes[u.v].visited!=thisIteration)
								{
									 queue.addFirst(u.v);
									 nodes[u.v].visited=thisIteration;
									 nodes[u.v].p=v;						  
									 nodes[u.v].d=u.edge;
								}
						  }
					 }
				}
				return null;
		  }
	 }

    static StringTokenizer st = new StringTokenizer("");
    static BufferedReader input = new BufferedReader(new InputStreamReader(System.in));

    static String nextToken() throws Exception {
        while (!st.hasMoreTokens()) 
          st = new StringTokenizer(input.readLine());
        return st.nextToken();
    }
    
    static int nextInt() throws Exception {
		  return Integer.parseInt(nextToken());
    }

    public static void main(String[] args) throws Exception 
	 {
		  new oo().main();
	 }

	 private void main() throws Exception 
	 {
		  int M,N;
        while(((N=nextInt())>0)&&((M=nextInt())>=0))
		  {
				Graph g=new Graph(N,M);				
				for(int i=0;i<M;i++)
				{
					 int v1=nextInt(),
						  v2=nextInt();
					 g.addEdgeToSpanningForrest(v1,v2);
				}
				String parity=input.readLine().trim();
				int nodd=0;
				for(int i=0;i<parity.length();i++)
				{
					 char p=Character.toLowerCase(parity.charAt(i));
					 if(p=='o')
					 {
						  g.nodes[i+1].parity=Parity.odd;
						  nodd++;
					 }
					 else if(p=='e')
					 {
						  g.nodes[i+1].parity=Parity.even;
					 }
					 else
					 {
						  System.out.println("Error - SubgraphWithParity: '"+p+"' is not a parity symbol");
						  System.exit(1);
					 }
				}
			   if(nodd==0)
				{
					 System.out.println("0");    //all node degrees are even in discrete graph
				}
				else if(nodd%2==1)              // sum(degrees)=2*N
				{
					 System.out.println("impossible");
				}
				else  
				{  		
					 int RESULTSIZE=0;
					 boolean impossible=false;
					 for(int i=1;i<g.nodes.length;i++)
					 {
						  if(!g.nodes[i].processed &&
							  g.nodes[i].parity==Parity.odd)
						  {
								ArrayList<Integer> path=g.findPathToOdd(i);								
								if(path==null)
								{
									 System.out.println("impossible");
									 impossible=true;
									 break;
								}				  
								else
								{
									 for(int k=0;k<path.size();k++)
									 {
										  g.edges.get(path.get(k)).in_result^=1;									
									 }
								}
						  }				  						  						 
					 }
					 if(!impossible)
					 {
						  StringBuffer sb=new StringBuffer("");					 
						  for(int m=0;m<g.edges.size();m++)
						  {							  
								if(g.edges.get(m).in_result==1)
								{
									 RESULTSIZE++;
									 sb.append(g.edges.get(m).v1+" "+g.edges.get(m).v2+newline);
								}
						  }
						  System.out.println(RESULTSIZE);
						  System.out.print(sb);
					 }
				}
		  }
		  System.exit(0);
    }
}